#!/bin/bash

# where to install packages from - full path to slackware directory,
# the one which contains /a /ap /d /kde /x etc....
SLACKWARE="/mnt/sda7/linux/slack-mirror/slackware-current"
SLAX="/mnt/sda7/linux/slax-packages"
LINUX_LIVE="/tmp/linux-live-5.1.4"
SLAX_VERSION="SLAX 5.0.6"

# variables
UNION="/mnt/union"
SLAXDIR="/tmp/slax_snapshots"

slackware_install()
{
   ls -1 $SLACKWARE/$1* | while read PKG; do
     OFFSET=$((${#SLACKWARE}+${#1}+2))
     if [ `echo "$PKG" | cut -b $OFFSET- | egrep "^[-][^-]+-[^-]+-[^-]+.tgz\$"` ]; then
        echo slackware_install $1
        installpkg -root $UNION $PKG  >/dev/null
     fi
   done
}

slax_install()
{
   ls -1 $SLAX/$1* | while read PKG; do
     OFFSET=$((${#SLAX}+${#1}+2))
     if [ `echo "$PKG" | cut -b $OFFSET- | egrep "^[-][^-]+-[^-]+-[^-]+.tgz\$"` ]; then
        echo slax_install $1
        installpkg -root $UNION $PKG  >/dev/null
     fi
   done
}

copy2root()
{
   cp -rp $1/* $UNION
}

# remove files which are already installed in $1
# so the module won't include duplicated files
# $1 = original files root (source for comparing)
# $2 = new files root, remove duplicates from here
#
function remove_duplicates()
{
   find "$2" | while read DUPLICATE; do
      ORIGFILE=$1/"${DUPLICATE:$((${#2}+1))}"
      if [ "$DUPLICATE" = "$ORIGFILE" ]; then continue; fi
      if [ ! -d "$DUPLICATE" -a -a "$ORIGFILE" ]; then
         diff --brief "$DUPLICATE" "$ORIGFILE" >/dev/null 2>/dev/null
         if [ $? = 0 ]; then # is the same, can be removed
            rm -v "$DUPLICATE"
            rmdir --ignore-fail-on-non-empty "`dirname $DUPLICATE`"
         fi
      fi
   done
}

# ---------------------------------
# how does it work?
# installpkg will use still the same directory: $UNION, but changes will be
# saved to several different directories. By using unionfs. Great!
# Finaly remove all duplicit files to save space, and create mo images.
# ---------------------------------

# add new directory to union (as a branch nr 0, read-write)
# so all union changes are stored in this new directory
# $1 = snapshot name
#
activate_new_layer()
{
   if [ "$SNAPSHOT" != "" ]; then unionctl $UNION --mode $SLAXDIR/$SNAPSHOT ro; fi
   LAYERNR=$(($LAYERNR+1))
   if [ $LAYERNR -lt 10 ]; then LAYERNR0="0"$LAYERNR; else LAYERNR0=$LAYERNR; fi
   SNAPSHOT=$LAYERNR0"_"$1
   echo "current layer: $SLAXDIR/$SNAPSHOT"
   mkdir -p $SLAXDIR/$SNAPSHOT
   unionctl $UNION --add --before 0 --mode rw $SLAXDIR/$SNAPSHOT
   if [ $? -ne 0 ]; then exit; fi
}

rm -Rf /tmp/slax_snapshots
rm -Rf /tmp/slax_backup

# setup union

mkdir -p $UNION
modprobe unionfs
if [ $? -ne 0 ]; then exit 1; fi
mount -t unionfs -o dirs=$UNION=ro unionfs $UNION
if [ $? -ne 0 ]; then exit 1; fi

# installpkg to all layers

activate_new_layer kernel
slax_install "/kernel/linux-kernel"
rm $UNION/boot/*
depmod -b $UNION

activate_new_layer core
slackware_install "/a/aaa_base"
slackware_install "/a/aaa_elflibs"
slackware_install "/a/acpid"
slackware_install "/a/bash"
slackware_install "/a/bin"
slackware_install "/a/bzip2"
slackware_install "/a/coreutils"
slackware_install "/a/cxxlibs"
slackware_install "/a/dcron"
slackware_install "/a/e2fsprogs"
slackware_install "/a/etc"
slackware_install "/a/findutils"
slackware_install "/a/floppy"
slackware_install "/a/gawk"
slackware_install "/a/gettext"
slackware_install "/a/getty-ps"
slackware_install "/a/glibc-solibs"
slackware_install "/a/gpm"
slackware_install "/a/grep"
slackware_install "/a/gzip"
slackware_install "/a/hdparm"
slackware_install "/a/hotplug"
slackware_install "/a/infozip"
slackware_install "/a/isapnptools"
slackware_install "/a/jfsutils"
slackware_install "/a/less"
slackware_install "/a/lilo"
slackware_install "/a/logrotate"
slackware_install "/a/module-init-tools"
slackware_install "/a/openssl-solibs"
slackware_install "/a/pciutils"
slackware_install "/a/pcmcia-cs"
slackware_install "/a/pkgtools"
slackware_install "/a/procps"
slackware_install "/a/reiserfsprogs"
slackware_install "/a/sed"
slackware_install "/a/shadow"
slackware_install "/a/slocate"
slackware_install "/a/sysklogd"
slackware_install "/a/sysvinit"
slackware_install "/a/tar"
slackware_install "/a/udev"
slackware_install "/a/umsdos-progs"
slackware_install "/a/usbutils"
slackware_install "/a/utempter"
slackware_install "/a/util-linux"
slackware_install "/a/xfsprogs"
slackware_install "/ap/amp"
slackware_install "/ap/ash"
slackware_install "/ap/bpe"
slackware_install "/ap/cdrtools"
slackware_install "/ap/dvd+rw-tools"
slackware_install "/ap/diffutils"
slackware_install "/ap/groff"
slackware_install "/ap/lvm"
slackware_install "/ap/man"
slackware_install "/ap/mc"
slackware_install "/ap/mdadm"
slackware_install "/ap/most"
slackware_install "/ap/rexima"
slackware_install "/ap/screen"
slackware_install "/ap/sudo"
slackware_install "/d/strace"
slackware_install "/d/perl"
slackware_install "/l/libtermcap"
slackware_install "/l/libusb"
slackware_install "/l/zlib"
slackware_install "/n/dhcpcd"
slackware_install "/n/iptables"
slackware_install "/n/nc"
slackware_install "/n/openssh"
slackware_install "/n/rdist"
slackware_install "/n/tcpip"
slackware_install "/n/wget"
slackware_install "/n/wireless-tools"
echo "slax.slackware-live.cd" >$UNION/etc/HOSTNAME
chmod ago-x $UNION/etc/rc.d/rc.sshd
echo $SLAX_VERSION >$UNION/etc/slax-version
rmdir $UNION/mnt/*
ldconfig -r $UNION
copy2root "./rootpatch"

activate_new_layer xwindow
slackware_install "/x/x11-fonts-cyrillic"
slackware_install "/x/x11-fonts-misc"
slackware_install "/x/x11-fonts-scale"
slackware_install "/x/x11"
slax_install "/standard/xfce-theme-engine"
ldconfig -r $UNION

activate_new_layer xap_libs
slackware_install "/ap/cdparanoia"
slackware_install "/l/aalib"
slackware_install "/l/atk"
slackware_install "/l/audiofile"
slackware_install "/l/glib"
slackware_install "/l/gtk+"
slackware_install "/l/gtk+2"
slackware_install "/l/imlib"
slackware_install "/l/libao"
slackware_install "/l/libart_lgpl"
slackware_install "/l/libexif"
slackware_install "/l/libglade"
slackware_install "/l/libidn"
slackware_install "/l/libjpeg"
slackware_install "/l/libmad"
slackware_install "/l/libmng"
slackware_install "/l/libpng"
slackware_install "/l/librsvg"
slackware_install "/l/libungif"
slackware_install "/l/libxml2"
slackware_install "/l/libxslt"
slackware_install "/l/pango"
slackware_install "/l/sdl"
slackware_install "/l/startup-notification"
ldconfig -r $UNION

activate_new_layer common
slackware_install "/a/cpio"
slackware_install "/a/cups"
slackware_install "/a/elvis"
slackware_install "/a/glibc-zoneinfo"
slackware_install "/a/kbd"
slackware_install "/a/smartmontools"
slackware_install "/ap/bc"
slackware_install "/ap/cdrdao"
slackware_install "/ap/flac"
slackware_install "/ap/joe"
slackware_install "/ap/jove"
slackware_install "/ap/lsof"
slackware_install "/ap/man-pages"
slackware_install "/ap/mpg321"
slackware_install "/ap/mt-st"
slackware_install "/ap/normalize"
slackware_install "/ap/rpm"
slackware_install "/ap/rzip"
slackware_install "/ap/seejpeg"
slackware_install "/ap/sox"
slackware_install "/ap/vorbis-tools"
slackware_install "/ap/workbone"
slackware_install "/d/m4"
slackware_install "/l/aspell"
slackware_install "/l/esound"
slackware_install "/l/expat"
slackware_install "/l/gdk-pixbuf"
slackware_install "/l/glib2"
slackware_install "/l/glut"
slackware_install "/l/lesstif"
slackware_install "/l/libgsf"
slackware_install "/l/libid3tag"
slackware_install "/l/libieee1284"
slackware_install "/l/libogg"
slackware_install "/l/libtiff"
slackware_install "/l/libvorbis"
slackware_install "/l/libwmf"
slackware_install "/l/mhash"
slackware_install "/l/mpeg_lib"
slackware_install "/l/ncurses"
slackware_install "/l/pcre"
slackware_install "/l/popt"
slackware_install "/l/svgalib"
slackware_install "/l/t1lib"
slackware_install "/l/taglib"
slackware_install "/l/wv2"
slackware_install "/l/libwpd"
slackware_install "/l/xaw3d"
slackware_install "/n/autofs"
slackware_install "/n/bind"
slackware_install "/n/cyrus-sasl"
slackware_install "/n/iproute2"
slackware_install "/n/iptraf"
slackware_install "/n/lynx"
slackware_install "/n/mutt"
slackware_install "/n/netwatch"
slackware_install "/n/nmap"
slackware_install "/n/openssl"
slackware_install "/n/pidentd"
slackware_install "/n/ppp"
slackware_install "/n/rdist"
slackware_install "/n/rp-pppoe"
slackware_install "/n/rsync"
slackware_install "/n/tcpdump"
slackware_install "/n/traceroute"
slackware_install "/n/whois"
ldconfig -r $UNION

activate_new_layer kde_base
slax_install "/kde/arts"
slackware_install "/kde/qt"
slackware_install "/kde/kdebase"
slackware_install "/kde/kdelibs"
ldconfig -r $UNION

activate_new_layer kde_apps
slax_install "/kde/kdegames"
slax_install "/kde/kdegraphics"
slax_install "/kde/kdemultimedia"
slax_install "/kde/kdenetwork"
slax_install "/kde/kdeutils"
slax_install "/kde/kdewebdev"
slax_install "/kde/k3b"
slax_install "/kde/kplayer"
slax_install "/kde/libmusicbrainz"
slax_install "/kde/libtunepimp"
ldconfig -r $UNION

activate_new_layer kde_office
slax_install "/kde/kdepim"
slax_install "/kde/koffice"
ldconfig -r $UNION

activate_new_layer slax
slax_install "standard/MPlayer"
slax_install "standard/checkinstall"
slax_install "standard/ctorrent"
slax_install "standard/fluxbox"
slax_install "standard/gpart"
slax_install "standard/id3lib"
slax_install "standard/lame"
slax_install "standard/netscape-plugins"
slax_install "standard/parted"
slax_install "standard/qiv"
slax_install "standard/rdesktop"
slax_install "standard/samba-stripped"
ldconfig -r $UNION

activate_new_layer killbill
. ./modules/killbill.sh
ldconfig -r $UNION

activate_new_layer popcorn
. ./modules/popcorn.sh
ldconfig -r $UNION

activate_new_layer devel
. ./modules/devel.sh
ldconfig -r $UNION

echo "syncing and unmounting union..."
umount $UNION

echo "removing unionfs .wh. files"
find $SLAXDIR -name ".wh.*" | xargs rm

echo "removing unneeded files..."
ls -1 $SLAXDIR | while read SNAPSHOT; do
   ./move_unneeded $SLAXDIR/$SNAPSHOT
done

LLDEST="`ls -d $SLAXDIR/??_core`"
echo $LLDEST
KDEDEST="`ls -d $SLAXDIR/??_kde_base`"
cd $LINUX_LIVE
./install $LLDEST
installpkg -root $KDEDEST $SLAX/kde/slax-kde-artwork*

## here we are using the feature that ls sorts files alphabeticaly
if [ 1 = 1 ]; then
   echo "removing duplicated files"
   ls -1 $SLAXDIR | while read SNAPSHOT; do
       ls -1 $SLAXDIR | while read SNAPSHOTDUPL; do
          if [ "$SNAPSHOT" \< "$SNAPSHOTDUPL" ]; then
             remove_duplicates $SLAXDIR/$SNAPSHOT $SLAXDIR/$SNAPSHOTDUPL
          fi
       done
   done
fi

echo "directories in $SLAXDIR created. Generate .mo files:"
rmdir $UNION

cd $SLAXDIR
ls -1 | while read DIR; do
   echo $DIR...
   mksquashfs $DIR $DIR.mo >/dev/null
   chmod ago-x $DIR.mo
done
